@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.h 6393 2008-08-13 13:34:30Z pborelli $
+ * $Id: gedit-document.h 6419 2008-08-16 16:53:47Z jessevdk $
  */
  
 #ifndef __GEDIT_DOCUMENT_H__
@@ -36,7 +36,6 @@
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcebuffer.h>
-#include <libgnomevfs/gnome-vfs.h>
 
 #include <gedit/gedit-encodings.h>
 
@@ -140,8 +139,7 @@ struct _GeditDocumentClass
 
 enum
 {
-	/* we use GIO error codes, so start at some high number? */
-	GEDIT_DOCUMENT_ERROR_EXTERNALLY_MODIFIED = 1 << 10,
+	GEDIT_DOCUMENT_ERROR_EXTERNALLY_MODIFIED,
 	GEDIT_DOCUMENT_ERROR_CANT_CREATE_BACKUP,
 	GEDIT_DOCUMENT_ERROR_TOO_BIG,
 	GEDIT_DOCUMENT_NUM_ERRORS 
