@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-help.h 4429 2005-12-12 17:28:04Z pborelli $
+ * $Id: gedit-help.h 6353 2008-08-06 19:45:23Z jessevdk $
  */
 
 #ifndef __GEDIT_HELP_H__
@@ -36,7 +36,7 @@
 G_BEGIN_DECLS
 
 gboolean	gedit_help_display (GtkWindow   *parent,
-				    const gchar *file_name, /* "gedit.xml" if NULL */
+				    const gchar *name, /* "gedit" if NULL */
 				    const gchar *link_id);
 				    
 G_END_DECLS
